@@ -14,11 +14,11 @@ Games::Cards::ShuffleTrack - Track cards through shuffles and cuts
 
 =head1 VERSION
 
-Version 0.01_3
+Version 0.01_4
 
 =cut
 
-our $VERSION = '0.01_3';
+our $VERSION = '0.01_4';
 
 my $cut_limits = {
 	normal  => [0.19, 0.82], # on a 52 cards deck, cut between 10 and 43 cards
@@ -39,13 +39,6 @@ my $decks = {
 };
 
 
-=head1 WARNING
-
-This module is in development stage still. In fact, it's still under specification.
-
-Some of the methods documented here haven't been fully implemented yet (nor has the module been uploaded to CPAN yet).
-
-
 =head1 SYNOPSIS
 
 This module allows you to simulate true and false shuffles and cuts.
@@ -192,9 +185,7 @@ Turning the deck reverses its order.
 sub turn {
 	my $self = shift;
 
-	$self->{'orientation'} = $self->orientation eq 'down' ?
-							 'up' : 'down';
-
+	$self->{'orientation'} = $self->orientation eq 'down' ? 'up' : 'down';
 
 	$self->_set_deck( reverse @{$self->get_deck} );
 
@@ -229,6 +220,33 @@ sub overhand_shuffle {
 		   $self
 }
 
+=head3 Hindu Shuffle
+
+=head4 hindu_shuffle
+
+In a Hindu shuffle the cards are moved from hand to the other in packets, the result being similar to that of running cuts (the difference being that the packets in an overhand shuffle may be smaller than the ones in a running cut sequence).
+
+	$deck->hindu_shuffle;
+
+You can specify how many times you want to go through the deck (which is basically the same thing as calling the method that many times):
+
+	$deck->hindu_shuffle( 2 );
+
+The Hindu shuffle differs in result from the Overhand shuffle in that the packets are usually thicker; the reason for this is that while in the Overhand shuffle it's the thumb that grabs the cards (and the thumb can easily carry just one or two cards) in the Hindu shuffle it's more than one finger accomplishing this task, grabbing the deck by the sides, which makes it more difficult (hence, rare) to cut just one or two cards.
+
+=cut
+
+sub hindu_shuffle {
+	my $self  = shift;
+	my $times = shift || 1;
+
+	$self->_packet_transfer( 4, 10 );
+
+	return $times > 1 ?
+		   $self->hindu_shuffle( $times - 1 ) :
+		   $self
+}
+
 sub _packet_transfer {
 	my $self = shift;
 	my $min  = shift;
@@ -467,6 +485,29 @@ sub cut_above {
 	return $self->cut( $self->find( $card ) - 1 );
 }
 
+=head3 Running Cuts
+
+Cut packets:
+
+    $deck->running_cuts();
+
+To do the procedure twice:
+
+    $deck->running_cuts( 2 );
+
+=cut
+
+sub running_cuts {
+	my $self  = shift;
+	my $times = shift || 1;
+
+	$self->_packet_transfer( 5, 15 );
+
+	return $times > 1 ?
+		   $self->overhand_shuffle( $times - 1 ) :
+		   $self
+}
+
 
 =head2 Finding cards
 
@@ -594,7 +635,7 @@ If the King of Hearts is just after the Ace of Spades, then the result is 1. If
 =cut
 
 sub distance {
-	my $self   = shift;
+	my $self        = shift;
 	my $first_card  = shift;
 	my $second_card = shift;
 
